@@ -15,13 +15,16 @@ QwtNullPaintDevice
 
 import os
 
-from qtpy.QtGui import QPaintEngine, QPainterPath, QPaintDevice
+from qtpy.QtCore import QObject
+from qtpy.QtGui import QPaintDevice, QPaintEngine, QPainterPath
 
 QT_API = os.environ["QT_API"]
 
 
-class QwtNullPaintDevice_PrivateData(object):
+class QwtNullPaintDevice_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.mode = QwtNullPaintDevice.NormalMode
 
 
@@ -51,7 +54,6 @@ class QwtNullPaintDevice_PaintEngine(QPaintEngine):
             try:
                 QPaintEngine.drawRects(self, rects, rectCount)
             except TypeError:
-                # PyQt <=4.9
                 QPaintEngine.drawRects(self, rects)
             return
         device.drawRects(rects, rectCount)
@@ -64,9 +66,8 @@ class QwtNullPaintDevice_PaintEngine(QPaintEngine):
             return
         if device.mode() != QwtNullPaintDevice.NormalMode and QT_API.startswith("pyqt"):
             try:
-                QPaintEngine.drawLines(lines, lineCount)
+                QPaintEngine.drawLines(self, lines, lineCount)
             except TypeError:
-                # PyQt <=4.9
                 QPaintEngine.drawLines(self, lines)
             return
         device.drawLines(lines, lineCount)
@@ -76,7 +77,7 @@ class QwtNullPaintDevice_PaintEngine(QPaintEngine):
         if device is None:
             return
         if device.mode() != QwtNullPaintDevice.NormalMode:
-            QPaintEngine.drawEllipse(rect)
+            QPaintEngine.drawEllipse(self, rect)
             return
         device.drawEllipse(rect)
 
@@ -94,9 +95,8 @@ class QwtNullPaintDevice_PaintEngine(QPaintEngine):
             return
         if device.mode() != QwtNullPaintDevice.NormalMode:
             try:
-                QPaintEngine.drawPoints(points, pointCount)
+                QPaintEngine.drawPoints(self, points, pointCount)
             except TypeError:
-                # PyQt <=4.9
                 QPaintEngine.drawPoints(self, points)
             return
         device.drawPoints(points, pointCount)
@@ -135,7 +135,7 @@ class QwtNullPaintDevice_PaintEngine(QPaintEngine):
         if device is None:
             return
         if device.mode() != QwtNullPaintDevice.NormalMode:
-            QPaintEngine.drawTextItem(pos, textItem)
+            QPaintEngine.drawTextItem(self, pos, textItem)
             return
         device.drawTextItem(pos, textItem)
 
@@ -144,7 +144,7 @@ class QwtNullPaintDevice_PaintEngine(QPaintEngine):
         if device is None:
             return
         if device.mode() != QwtNullPaintDevice.NormalMode:
-            QPaintEngine.drawTiledPixmap(rect, pixmap, subRect)
+            QPaintEngine.drawTiledPixmap(self, rect, pixmap, subRect)
             return
         device.drawTiledPixmap(rect, pixmap, subRect)
 
