@@ -132,8 +132,8 @@ class QwtPlot(QFrame):
         x = np.linspace(-10, 10, 500)
         plot = qwt.QwtPlot("Trigonometric functions")
         plot.insertLegend(qwt.QwtLegend(), qwt.QwtPlot.BottomLegend)
-        qwt.QwtPlotCurve.make(x, np.cos(x), "Cosinus", plot, linecolor="red", antialiased=True)
-        qwt.QwtPlotCurve.make(x, np.sin(x), "Sinus", plot, linecolor="blue", antialiased=True)
+        qwt.QwtPlotCurve.make(x, np.cos(x), "Cosine", plot, linecolor="red", antialiased=True)
+        qwt.QwtPlotCurve.make(x, np.sin(x), "Sine", plot, linecolor="blue", antialiased=True)
         plot.resize(600, 300)
         plot.show()
 
@@ -588,7 +588,7 @@ class QwtPlot(QFrame):
     def axisMargin(self, axisId):
         """
         :param int axisId: Axis index
-        :return: Margin in % of the canvas size
+        :return: Relative margin of the axis, as a fraction of the full axis range
 
         .. seealso::
 
@@ -871,15 +871,17 @@ class QwtPlot(QFrame):
 
     def setAxisMargin(self, axisId, margin):
         """
-        Set the margin of the scale widget
+        Set the relative margin of the axis, as a fraction of the full axis range
 
         :param int axisId: Axis index
-        :param float margin: Margin in % of the canvas size
+        :param float margin: Relative margin (float between 0 and 1)
 
         .. seealso::
 
             :py:meth:`axisMargin()`
         """
+        if not isinstance(margin, float) or margin < 0.0 or margin > 1.0:
+            raise ValueError("margin must be a float between 0 and 1")
         if self.axisValid(axisId):
             d = self.__axisData[axisId]
             if margin != d.margin:
@@ -946,15 +948,13 @@ class QwtPlot(QFrame):
             minValue = d.minValue
             maxValue = d.maxValue
             stepSize = d.stepSize
-            if d.margin is not None:
-                intv_i = intv[axisId].extend_fraction(d.margin)
-            else:
-                intv_i = intv[axisId]
-            if d.doAutoScale and intv_i.isValid():
+            if d.doAutoScale and intv[axisId].isValid():
                 d.isValid = False
-                minValue = intv_i.minValue()
-                maxValue = intv_i.maxValue()
-                d.scaleEngine.autoScale(d.maxMajor, minValue, maxValue, stepSize)
+                minValue = intv[axisId].minValue()
+                maxValue = intv[axisId].maxValue()
+                minValue, maxValue, stepSize = d.scaleEngine.autoScale(
+                    d.maxMajor, minValue, maxValue, stepSize, d.margin
+                )
             if not d.isValid:
                 d.scaleDiv = d.scaleEngine.divideScale(
                     minValue, maxValue, d.maxMajor, d.maxMinor, stepSize
@@ -1391,7 +1391,7 @@ class QwtPlot(QFrame):
             :py:meth:`QwtPlotItem.getCanvasMarginHint()`
         """
         maps = [self.canvasMap(axisId) for axisId in self.AXES]
-        self.drawItems(painter, self.__data.canvas.contentsRect(), maps)
+        self.drawItems(painter, QRectF(self.__data.canvas.contentsRect()), maps)
 
     def drawItems(self, painter, canvasRect, maps):
         """
@@ -1553,6 +1553,7 @@ class QwtPlot(QFrame):
         self.__data.layout.setLegendPosition(pos, ratio)
         if legend != self.__data.legend:
             if self.__data.legend and self.__data.legend.parent() is self:
+                self.__data.legend.setParent(None)
                 del self.__data.legend
             self.__data.legend = legend
             if self.__data.legend:
@@ -1560,9 +1561,9 @@ class QwtPlot(QFrame):
                 if self.__data.legend.parent() is not self:
                     self.__data.legend.setParent(self)
 
-                self.blockSignals(True)
+                self.legendDataChanged.disconnect(self.updateLegendItems)
                 self.updateLegend()
-                self.blockSignals(False)
+                self.legendDataChanged.connect(self.updateLegendItems)
 
                 lpos = self.__data.layout.legendPosition()
 
@@ -1706,7 +1707,6 @@ class QwtPlotItem_PrivateData(QObject):
         self.yAxis = QwtPlot.yLeft
         self.legendIconSize = QSize(8, 8)
         self.title = None  # QwtText
-        self.icon = None
 
 
 class QwtPlotItem(object):
@@ -1915,29 +1915,6 @@ class QwtPlotItem(object):
         """
         return self.__data.title
 
-    def setIcon(self, icon):
-        """
-        Set item icon
-
-        :param icon: Icon
-        :type icon: QIcon
-
-        .. seealso::
-
-            :py:meth:`icon()`
-        """
-        self.__data.icon = icon
-
-    def icon(self):
-        """
-        :return: Icon of the item
-
-        .. seealso::
-
-            :py:meth:`setIcon()`
-        """
-        return self.__data.icon
-
     def setItemAttribute(self, attribute, on=True):
         """
         Toggle an item attribute
@@ -2160,7 +2137,7 @@ class QwtPlotItem(object):
         import warnings
 
         warnings.warn(
-            "`setAxis` has been removed in Qwt6: " "please use `setAxes` instead",
+            "`setAxis` has been removed in Qwt6: please use `setAxes` instead",
             RuntimeWarning,
         )
         self.setAxes(xAxis, yAxis)
