@@ -13,11 +13,8 @@ QwtPlotDirectPainter
    :members:
 """
 
+from qtpy.QtCore import QEvent, QObject, Qt
 from qtpy.QtGui import QPainter, QRegion
-from qtpy.QtCore import QObject, Qt, QEvent
-from qtpy import QtCore as QC
-
-QT_MAJOR_VERSION = int(QC.__version__.split(".")[0])
 
 from qwt.plot import QwtPlotItem
 from qwt.plot_canvas import QwtPlotCanvas
@@ -36,12 +33,16 @@ def qwtRenderItem(painter, canvasRect, seriesItem, from_, to):
 
 def qwtHasBackingStore(canvas):
     return (
-        canvas.testPaintAttribute(QwtPlotCanvas.BackingStore) and canvas.backingStore()
+        canvas.testPaintAttribute(QwtPlotCanvas.BackingStore)
+        and canvas.backingStore() is not None
+        and not canvas.backingStore().isNull()
     )
 
 
-class QwtPlotDirectPainter_PrivateData(object):
+class QwtPlotDirectPainter_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.attributes = 0
         self.hasClipping = False
         self.seriesItem = None  # QwtPlotSeriesItem
@@ -210,25 +211,16 @@ class QwtPlotDirectPainter(QObject):
             return
         canvas = seriesItem.plot().canvas()
         canvasRect = canvas.contentsRect()
-        plotCanvas = canvas  # XXX: cast to QwtPlotCanvas
-        if plotCanvas and qwtHasBackingStore(plotCanvas):
-            painter = QPainter(
-                plotCanvas.backingStore()
-            )  # XXX: cast plotCanvas.backingStore() to QPixmap
+        if canvas and qwtHasBackingStore(canvas):
+            painter = QPainter(canvas.backingStore())
             if self.__data.hasClipping:
                 painter.setClipRegion(self.__data.clipRegion)
             qwtRenderItem(painter, canvasRect, seriesItem, from_, to)
             painter.end()
             if self.testAttribute(self.FullRepaint):
-                plotCanvas.repaint()
+                canvas.repaint()
                 return
-        immediatePaint = True
-        if not canvas.testAttribute(Qt.WA_WState_InPaintEvent):
-            if QT_MAJOR_VERSION >= 5 or not canvas.testAttribute(
-                Qt.WA_PaintOutsidePaintEvent
-            ):
-                immediatePaint = False
-        if immediatePaint:
+        if canvas.testAttribute(Qt.WA_WState_InPaintEvent):
             if not self.__data.painter.isActive():
                 self.reset()
                 self.__data.painter.begin(canvas)
