@@ -13,7 +13,26 @@ QwtPlotRenderer
    :members:
 """
 
-from __future__ import division
+import math
+import os.path as osp
+
+from qtpy.compat import getsavefilename
+from qtpy.QtCore import QObject, QRect, QRectF, QSizeF, Qt
+from qtpy.QtGui import (
+    QColor,
+    QImage,
+    QImageWriter,
+    QPageSize,
+    QPaintDevice,
+    QPainter,
+    QPainterPath,
+    QPalette,
+    QPen,
+    QTransform,
+)
+from qtpy.QtPrintSupport import QPrinter
+from qtpy.QtSvg import QSvgGenerator
+from qtpy.QtWidgets import QFileDialog
 
 from qwt.painter import QwtPainter
 from qwt.plot import QwtPlot
@@ -21,26 +40,6 @@ from qwt.plot_layout import QwtPlotLayout
 from qwt.scale_draw import QwtScaleDraw
 from qwt.scale_map import QwtScaleMap
 
-from qtpy.QtGui import (
-    QPainter,
-    QImageWriter,
-    QImage,
-    QColor,
-    QPaintDevice,
-    QTransform,
-    QPalette,
-    QPainterPath,
-    QPen,
-)
-from qtpy.QtWidgets import QFileDialog
-from qtpy.QtPrintSupport import QPrinter
-from qtpy.QtCore import Qt, QRect, QRectF, QObject, QSizeF
-from qtpy.QtSvg import QSvgGenerator
-from qtpy.compat import getsavefilename
-
-import math
-import os.path as osp
-
 
 def qwtCanvasClip(canvas, canvasRect):
     """
@@ -56,8 +55,10 @@ def qwtCanvasClip(canvas, canvasRect):
     return canvas.borderPath(r)
 
 
-class QwtPlotRenderer_PrivateData(object):
+class QwtPlotRenderer_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.discardFlags = QwtPlotRenderer.DiscardNone
         self.layoutFlags = QwtPlotRenderer.DefaultLayout
 
@@ -243,12 +244,20 @@ class QwtPlotRenderer(QObject):
         if fmt in ("pdf", "ps"):
             printer = QPrinter()
             if fmt == "pdf":
-                printer.setOutputFormat(QPrinter.PdfFormat)
+                try:
+                    printer.setOutputFormat(QPrinter.PdfFormat)
+                except AttributeError:
+                    # PyQt6 on Linux
+                    printer.setPrinterName("")
             else:
                 printer.setOutputFormat(QPrinter.PostScriptFormat)
-            printer.setColorMode(QPrinter.Color)
+            try:
+                printer.setColorMode(QPrinter.Color)
+            except AttributeError:
+                # PyQt6 on Linux
+                pass
             printer.setFullPage(True)
-            printer.setPaperSize(sizeMM, QPrinter.Millimeter)
+            printer.setPageSize(QPageSize(sizeMM, QPageSize.Millimeter))
             printer.setDocName(title)
             printer.setOutputFileName(filename)
             printer.setResolution(resolution)
@@ -358,8 +367,8 @@ class QwtPlotRenderer(QObject):
         invtrans, _ok = transform.inverted()
         layoutRect = invtrans.mapRect(plotRect)
         if not (self.__data.discardFlags & self.DiscardBackground):
-            left, top, right, bottom = plot.layout().getContentsMargins()
-            layoutRect.adjust(left, top, -right, -bottom)
+            mg = plot.contentsMargins()
+            layoutRect.adjust(mg.left(), mg.top(), -mg.right(), -mg.bottom())
 
         layout = plot.plotLayout()
         baseLineDists = canvasMargins = [None] * len(QwtPlot.AXES)
@@ -369,7 +378,10 @@ class QwtPlotRenderer(QObject):
             if self.__data.layoutFlags & self.FrameWithScales:
                 scaleWidget = plot.axisWidget(axisId)
                 if scaleWidget:
-                    baseLineDists[axisId] = max(scaleWidget.getContentsMargins())
+                    mgn = scaleWidget.contentsMargins()
+                    baseLineDists[axisId] = max(
+                        [mgn.left(), mgn.top(), mgn.right(), mgn.bottom()]
+                    )
                     scaleWidget.setMargin(0)
                 if not plot.axisEnabled(axisId):
                     #  When we have a scale the frame is painted on
@@ -432,7 +444,8 @@ class QwtPlotRenderer(QObject):
         for axisId in QwtPlot.AXES:
             scaleWidget = plot.axisWidget(axisId)
             if scaleWidget:
-                baseDist = max(scaleWidget.getContentsMargins())
+                mgn = scaleWidget.contentsMargins()
+                baseDist = max([mgn.left(), mgn.top(), mgn.right(), mgn.bottom()])
                 startDist, endDist = scaleWidget.getBorderDistHint()
                 self.renderScale(
                     plot,
@@ -554,8 +567,8 @@ class QwtPlotRenderer(QObject):
 
         :param qwt.plot.QwtPlot plot: Plot widget
         :param QPainter painter: Painter
-        :param qwt.scale_map.QwtScaleMap maps: mapping between plot and paint device coordinates
         :param QRectF rect: Bounding rectangle
+        :param qwt.scale_map.QwtScaleMap maps: mapping between plot and paint device coordinates
         """
         canvas = plot.canvas()
         r = canvasRect.adjusted(0.0, 0.0, -1.0, 1.0)
@@ -723,3 +736,4 @@ class QwtPlotRenderer(QObject):
             return False
         self.renderDocument(plot, filename, sizeMM, resolution)
         return True
+        return True
