@@ -11,7 +11,7 @@ SHOW = True  # Show test in GUI-based test launcher
 import os
 
 import numpy as np
-from qtpy.QtCore import QRect, Qt, QTime
+from qtpy.QtCore import QRectF, Qt, QTime
 from qtpy.QtGui import QBrush, QColor
 from qtpy.QtWidgets import QLabel, QVBoxLayout, QWidget
 
@@ -195,17 +195,18 @@ class CpuStat:
         return 100.0 * userDelta / totalDelta, 100.0 * systemDelta / totalDelta
 
     def upTime(self):
-        result = QTime()
+        result = QTime(0, 0, 0)
         for item in self.procValues:
             result = result.addSecs(int(0.01 * item))
         return result
 
     def __lookup(self):
         if os.path.exists("/proc/stat"):
-            for line in open("/proc/stat"):
-                words = line.split()
-                if words[0] == "cpu" and len(words) >= 5:
-                    return [float(w) for w in words[1:]]
+            with open("/proc/stat") as file:
+                for line in file:
+                    words = line.split()
+                    if words[0] == "cpu" and len(words) >= 5:
+                        return [float(w) for w in words[1:]]
         else:
             result = CpuStat.dummyValues[CpuStat.counter]
             CpuStat.counter += 1
@@ -224,7 +225,7 @@ class CpuPieMarker(QwtPlotMarker):
 
     def draw(self, painter, xMap, yMap, rect):
         margin = 5
-        pieRect = QRect()
+        pieRect = QRectF()
         pieRect.setX(rect.x() + margin)
         pieRect.setY(rect.y() + margin)
         pieRect.setHeight(int(yMap.transform(80.0)))
@@ -262,7 +263,7 @@ class Background(QwtPlotItem):
 
     def draw(self, painter, xMap, yMap, rect):
         c = QColor(Qt.white)
-        r = QRect(rect)
+        r = QRectF(rect)
 
         for i in range(100, 0, -10):
             r.setBottom(int(yMap.transform(i - 10)))
